@@ -1,5 +1,6 @@
 plot.PCoABootstrap <- function(x, F1=1, F2=2, Move2Center=TRUE, BootstrapPlot="Ellipse", confidence=0.95, Colors=NULL, ...){
-  if (class(x)!="PCoABootstrap") stop("Youmust provide an object of class PCoABootstrap")
+  clasex=class(x)
+  if (clasex!="PCoABootstrap") stop("Youmust provide an object of class PCoABootstrap")
   if (is.null(Colors)) Colors = matrix(1, n, 1)
   
   n=length(x$Coordinates)
